@@ -1,4 +1,4 @@
-`LocalF` <-
+LocalF <-
 function (x, phi) 
 {
     n <- length(x)
