@@ -1,4 +1,4 @@
-`phieta` <-
+phieta <-
 function (x, phi) 
 {
     n <- length(x)
